@@ -8,33 +8,11 @@ use parent qw/Exporter/;
 our @EXPORT = qw/unbro/;
 our @EXPORT_OK = @EXPORT;
 
-our $VERSION = '0.001001';
+our $VERSION = '0.002';
 
 require XSLoader;
 XSLoader::load('IO::Compress::Brotli', $VERSION);
 
-sub create {
-	my ($class) = @_;
-	my $state = BrotliCreateState();
-	bless \$state, $class
-}
-
-sub DESTROY {
-	my ($self) = @_;
-	BrotliDestroyState($$self)
-}
-
-sub decompress {
-	my ($self, $data) = @_;
-	BrotliDecompressStream($$self, $data)
-}
-
-# Untested, probably not working
-sub set_dictionary {
-	my ($self, $dict) = @_;
-	BrotliSetCustomDictionary($$self, $dict)
-}
-
 1;
 __END__
 
@@ -115,9 +93,22 @@ Brotli source code: L<https://github.com/google/brotli/>
 
 Marius Gavrilescu, E<lt>marius@ieval.roE<gt>
 
+The encoder bindings, modernisation of the decoder bindings and a
+clean up of the overall project were contributed by:
+
+=over
+
+=item Quim Rovira, E<lt>quim@rovira.catE<gt>
+
+=item Ævar Arnfjörð Bjarmason, E<lt>avarab@gmail.comE<gt>
+
+=item Marcell Szathmári
+
+=item Mattia Barbon, E<lt>mattia@barbon.orgE<gt>
+
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2015 by Marius Gavrilescu
+Copyright (C) 2015-2016 by Marius Gavrilescu
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.20.2 or,
